@@ -54,6 +54,14 @@ def __configure_fastapi(tracer_provider, fastapi_app=None):
             response.headers[__SPAN_ID_HEADER_NAME] = format(trace.get_current_span().get_span_context().span_id, 'x')
             return response
 
+def get_current_trace_id():
+    ctx = get_context()
+    if ctx and __TRACE_ID_HEADER_NAME in ctx:
+        trace_id = ctx[__TRACE_ID_HEADER_NAME]
+        if trace_id and trace_id != "0":
+            return trace_id
+    return None
+
 def get_context():
     result = {}
     ctx = trace.get_current_span().get_span_context()
